@@ -1,4 +1,4 @@
-
+import pandas as pd
 
 
 
@@ -47,8 +47,13 @@ class Encoder:
 
 
 
-    def encode_dataframe(self, df):
- 
+    def encode_dataframe(self, 
+                         df : pd.DataFrame, 
+                         ) -> pd.DataFrame: 
+
+        if not isinstance(df, pd.core.frame.DataFrame):
+            raise TypeError('The df must be a pandas.core.frame.DataFrame instance.')
+
         self.encoder_pool = {}
         self.decoder_pool = {}
         self.encoded_columns = []
@@ -95,7 +100,13 @@ class Encoder:
 
 
 
-    def decode_dataframe(self, df):
+    def decode_dataframe(self, 
+                         df : pd.DataFrame, 
+                         ) -> pd.DataFrame: 
+
+        if not isinstance(df, pd.core.frame.DataFrame):
+            raise TypeError('The df must be a pandas.core.frame.DataFrame instance.')
+
         for col in self.encoded_columns:
             df[col] = self.decode_column(df[[col]], col)
         return df
