@@ -359,7 +359,14 @@ class Snaplib__222:
         Select bests features for modeling and return list with bad features required to be droped.
 
         Use case:
-        features_to_drop = Snaplib().features_selection_regr(algorithms, df, target, metric, cv, verbose=0):
+        features_to_drop = Snaplib().features_selection_regr(algorithms, 
+                                                             df, 
+                                                             target, 
+                                                             metric, 
+                                                             cv, 
+                                                             verbose=0, 
+                                                             early_stopping_rounds=0)
+        
         df.drop(features_to_drop, inplace=True, axis=1)
 
 
@@ -403,7 +410,14 @@ class Snaplib__222:
         Select bests features for modeling and return list with bad features required to be droped.
         
         Use case:
-        features_to_drop = Snaplib().features_selection_clsf(algorithms, df, target, metric, cv, verbose=0):
+        features_to_drop = Snaplib().features_selection_clsf(algorithms, 
+                                                             df, 
+                                                             target, 
+                                                             metric, 
+                                                             cv, 
+                                                             verbose=0,  
+                                                             early_stopping_rounds=0)
+        
         df.drop(features_to_drop, inplace=True, axis=1)
 
 
